all messages for Emacs-related lists mirrored at yhetil.org
 help / color / mirror / code / Atom feed
* tcl.el typo fixes
@ 2002-03-28 15:55 Ville Skyttä
  0 siblings, 0 replies; only message in thread
From: Ville Skyttä @ 2002-03-28 15:55 UTC (permalink / raw)


[-- Attachment #1: Type: text/plain, Size: 99 bytes --]

Hello,

here's a couple of typo fixes for tcl.el.

-- 
Ville Skyttä
ville.skytta@xemacs.org

[-- Attachment #2: tcl-typos.patch --]
[-- Type: text/plain, Size: 1230 bytes --]

--- tcl.el.1.66	Thu Mar 28 17:41:42 2002
+++ tcl.el	Thu Mar 28 17:44:39 2002
@@ -76,7 +76,7 @@
 ;;   middle of a defun, or between defuns.  should notice if point is
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
 ;;   of the preceeding line, like this:
 ;;      [list something \
 ;;            something-else]
 ;; * There is a request that indentation work like this:
@@ -988,7 +988,7 @@
 ;;
 
 (defun tcl-imenu-create-index-function ()
-  "Generate alist of indices for imenu."
+  "Generate alist of indices for `imenu'."
   (let ((re (concat tcl-proc-regexp "\\([^ \t\n{]+\\)"))
 	alist prev-pos)
     (goto-char (point-min))
@@ -1189,7 +1189,7 @@
   "Return t if point is just after the `#' beginning a real comment.
 Does not check to see if previous char is actually `#'.
 A real comment is either at the beginning of the buffer,
-preceeded only by whitespace on the line, or has a preceeding
+preceded only by whitespace on the line, or has a preceding
 semicolon, opening brace, or opening bracket on the same line."
   (save-excursion
     (backward-char)

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2002-03-28 15:55 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -76,7 +76,7 @@
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
-;;   of the preceeding line, like this:
+;;   of the preceding line, like this:
 ;;      [list something \
 ;;            something-else]
2002-03-28 15:55 tcl.el typo fixes Ville Skyttä

Code repositories for project(s) associated with this external index

	https://git.savannah.gnu.org/cgit/emacs.git
	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.